@@ -1,3 +1,4 @@
+#include "path_helper.h"
 #include <errno.h>
 #include <stdbool.h>
 #include <stdio.h>
@@ -6,8 +7,11 @@
 
 static int run = -1;
 
-void on_connect(struct mosquitto *mosq, void *obj, int rc)
+
+static void on_connect(struct mosquitto *mosq, void *obj, int rc)
 {
+	(void)obj;
+
 	if(rc){
 		exit(1);
 	}else{
@@ -15,30 +19,48 @@ void on_connect(struct mosquitto *mosq, void *obj, int rc)
 	}
 }
 
-void on_disconnect(struct mosquitto *mosq, void *obj, int rc)
+
+static void on_disconnect(struct mosquitto *mosq, void *obj, int rc)
 {
+	(void)mosq;
+	(void)obj;
+
 	run = rc;
 }
 
+
 int main(int argc, char *argv[])
 {
 	int rc;
 	struct mosquitto *mosq;
+	int port;
 
-	int port = atoi(argv[1]);
+	if(argc < 2){
+		return 1;
+	}
+	port = atoi(argv[1]);
 
 	mosquitto_lib_init();
 
 	mosq = mosquitto_new("08-ssl-connect-no-auth", true, NULL);
-	mosquitto_tls_set(mosq, "../ssl/all-ca.crt", NULL, NULL, NULL, NULL);
+	if(mosq == NULL){
+		return 1;
+	}
+	char cafile[4096];
+	cat_sourcedir_with_relpath(cafile, "/../../ssl/test-root-ca.crt");
+	mosquitto_tls_set(mosq, cafile, NULL, NULL, NULL, NULL);
 	mosquitto_connect_callback_set(mosq, on_connect);
 	mosquitto_disconnect_callback_set(mosq, on_disconnect);
 
 	rc = mosquitto_connect(mosq, "localhost", port, 60);
+	if(rc != MOSQ_ERR_SUCCESS){
+		return rc;
+	}
 
 	while(run == -1){
 		mosquitto_loop(mosq, -1, 1);
 	}
+	mosquitto_destroy(mosq);
 
 	mosquitto_lib_cleanup();
 	return run;
